@@ -26,7 +26,7 @@ def getenv_int(key) -> int:
 
 
 def get_cache_datetime(path) -> datetime:
-    return datetime.fromtimestamp(min(os.path.getatime(path), os.path.getctime(path), os.path.getmtime(path)))
+    return datetime.fromtimestamp(os.path.getmtime(path))
 
 
 async def download_person(pid: str) -> Optional[ElementTree.Element]:
